==> libbpp-phyl_2.0.3.orig.tar.gz: bpp-phyl-2.0.3/src/Bpp/Phyl/Simulation/SequenceSimulator.h <==
//
// File: SequenceSimulator.h
// Created by: Julien Dutheil
// Created on: Wed Feb  4 16:30:51 2004
//

/*
Copyright or © or Copr. CNRS, (November 16, 2004)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#ifndef _SEQUENCESIMULATOR_H_
#define _SEQUENCESIMULATOR_H_

#include <Bpp/Clonable.h>

// From SeqLib:
#include <Bpp/Seq/Container/SiteContainer.h>

namespace bpp
{

/**
 * @brief The SequenceSimulator interface.
 * SequenceSimulator classes can simulate whole datasets.
 */
class SequenceSimulator:
  public virtual Clonable
{
  public:
    SequenceSimulator() {}
    virtual ~SequenceSimulator() {}

#ifndef NO_VIRTUAL_COV
    SequenceSimulator * clone() const = 0;
#endif
  
  public:
    virtual SiteContainer * simulate(unsigned int numberOfSites) const = 0;
    virtual const Alphabet * getAlphabet() const = 0;  
};

} //end of namespace bpp.

#endif  //_SEQUENCESIMULATOR_H_

==> libbpp-phyl_2.1.0.orig.tar.gz: bpp-phyl-2.1.0/src/Bpp/Phyl/Simulation/SequenceSimulator.h <==
//
// File: SequenceSimulator.h
// Created by: Julien Dutheil
// Created on: Wed Feb  4 16:30:51 2004
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)

This software is a computer program whose purpose is to provide classes
for phylogenetic data analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#ifndef _SEQUENCESIMULATOR_H_
#define _SEQUENCESIMULATOR_H_

#include <Bpp/Clonable.h>

// From SeqLib:
#include <Bpp/Seq/Container/SiteContainer.h>

namespace bpp
{

/**
 * @brief The SequenceSimulator interface.
 * SequenceSimulator classes can simulate whole datasets.
 */
class SequenceSimulator:
  public virtual Clonable
{
  public:
    SequenceSimulator() {}
    virtual ~SequenceSimulator() {}

#ifndef NO_VIRTUAL_COV
    SequenceSimulator * clone() const = 0;
#endif
  
  public:
    virtual SiteContainer * simulate(size_t numberOfSites) const = 0;
    virtual const Alphabet * getAlphabet() const = 0;  
};

} //end of namespace bpp.

#endif  //_SEQUENCESIMULATOR_H_
